==> toycars-0.3.0.tar.gz: toycars-0.3.0/src/NeedleImage.cpp <==
/*
	Copyright (C) 2005 by Ruben Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Zilibowitz on 23/01/05.
 */

#include "NeedleImage.h"
#include "ScException.h"
#include "SDL.h"
#include "SDL_image.h"

const char kNeedleImageFile[] = "images/needle.png";
const double kNeedleImageWidth = 8;

NeedleImage::NeedleImage() : needleImage(NULL), angle(0)
{
	ScPixelData needleImageData;
	SDL_Surface* img;
	
	img = IMG_Load(kNeedleImageFile);
	if (img == NULL)
		ScThrowErr("Could not load needle image file");
	
	needleImageData.pitch = img->pitch;
	needleImageData.bytes_pp = img->format->BytesPerPixel;
	needleImageData.internalformat = GL_RGBA;
	needleImageData.width = img->w;
	needleImageData.height = img->h;
	needleImageData.format = GL_RGBA;
	needleImageData.type = GL_UNSIGNED_BYTE;
	needleImageData.pixels = (const char*)img->pixels;
	
	needleImage = new ScImage(0, needleImageData, true);
	
	SDL_FreeSurface(img);
}

NeedleImage::~NeedleImage()
{
	delete needleImage;
}

void NeedleImage::draw()
{
	glColor4ub(255, 255, 255, 255);
	glEnable(GL_TEXTURE_2D);
	glEnable(GL_BLEND);
	glRotatef(angle, 0, 0, -1);
	needleImage->draw(-kNeedleImageWidth*0.5, -kNeedleImageWidth*0.5);
}

==> toycars-0.3.3.tar.gz: toycars-0.3.3/src/NeedleImage.cpp <==
/*
	Copyright (C) 2005 by Ruben Henner Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Henner Zilibowitz on 23/01/05.
 */

#include "NeedleImage.h"
#include "ScException.h"
#include "SDL.h"
#include "SDL_image.h"

const char kNeedleImageFile[] = "images/needle.png";
const double kNeedleImageWidth = 8;

NeedleImage::NeedleImage() : needleImage(NULL), angle(0)
{
	ScPixelData needleImageData;
	SDL_Surface* img;
	
	img = IMG_Load(kNeedleImageFile);
	if (img == NULL)
		ScThrowErr("Could not load needle image file");
	
	needleImageData.pitch = img->pitch;
	needleImageData.bytes_pp = img->format->BytesPerPixel;
	needleImageData.internalformat = GL_RGBA;
	needleImageData.width = img->w;
	needleImageData.height = img->h;
	needleImageData.format = GL_RGBA;
	needleImageData.type = GL_UNSIGNED_BYTE;
	needleImageData.pixels = (const char*)img->pixels;
	
	needleImage = new ScImage(0, needleImageData, true);
	
	SDL_FreeSurface(img);
}

NeedleImage::~NeedleImage()
{
	delete needleImage;
}

void NeedleImage::draw()
{
	glColor4ub(255, 255, 255, 255);
	glEnable(GL_TEXTURE_2D);
	glEnable(GL_BLEND);
	glRotatef(angle, 0, 0, -1);
	needleImage->draw(-kNeedleImageWidth*0.5, -kNeedleImageWidth*0.5);
}
